package MyApp1::Schema::ResultSet::CD;

use strict;
use warnings;

use base 'DBIx::Class::ResultSet';

1; # eof